<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 01/11/19
 * Time: 18.05
 */

namespace FiloBlu\Rma\Plugin\Model;
use Exception;
use FiloBlu\Rma\Helper\InstallHelper;
use Psr\Log\LoggerInterface;
use FiloBlu\Rma\Helper\ChangeSizeOrder;

class ChangeSizeOrderPlugin
{
        
 
    protected $changSizeItems = [];

    /**
     * @var LoggerInterface
     */
    protected $logger;
    
    /**
     * @var ChangeSizeOrder
     */
    protected $changeSizeOrder;


    /**
     * ChangeSizeOrderPlugin constructor.
     * @param LoggerInterface $logger
     * @param ChangeSizeOrder $changeSizeOrder
     */
    public function __construct(LoggerInterface $logger,
                                ChangeSizeOrder $changeSizeOrder)
    {
        $this->logger = $logger;
        $this->changeSizeOrder = $changeSizeOrder;
    }


    /**
     * @param \Magento\Rma\Model\Rma $subject
     * @param $result
     * @return mixed
     */
    public function afterSaveRma(\Magento\Rma\Model\Rma $subject , $result)
    {
        try {

            if ($result && isset($result['items'])) {
                $rmaItems = $result['items'];
                $parentProducts = [];
                foreach ($rmaItems as $item){
                    $autoApproveRma = false;
                    $standardReasonId = isset($item['reason']) ? $item['reason'] : 0;
                    $conditionId = isset($item['condition']) ? $item['condition'] : 0;
                    
                    //checkIfChangeSize
                    if(isset($item->getData()[InstallHelper::CHANGE_SIZE_RMA_ATTRIBUTE_CODE]) && $item->getData()[InstallHelper::CHANGE_SIZE_RMA_ATTRIBUTE_CODE] != "" ){
                        $changeProductId = $item->getData()[InstallHelper::CHANGE_SIZE_RMA_ATTRIBUTE_CODE];
                        $parentProducts [] = $item->getProductSku();
                        $this->changSizeItems [] = ['product_id'=>$changeProductId,'qty'=>$item['qty_requested']];
                    }
                }
                if(count($this->changSizeItems)>0){
                    $customEmail =$subject->getCustomerCustomEmail();
                    if(isset($customEmail) && $customEmail !=""){
                        $subject->getOrder()->setCustomerEmail($customEmail);
                    }
                    $this->createChangeSizeOrder($subject->getOrder(),$this->changSizeItems,$subject->getEntityId(),$parentProducts);

                    //reset changeSizeItems
                    $this->changSizeItems = [];
                }
            }
        }
        catch (\NoSuchElementException $e){
            $this->logger->critical($e->getMessage(),['exception']);
        }
        catch (\Exception $e){
            $this->logger->critical($e->getMessage(),['exception']);
        }
        return $result;
    }

    /**
     * @param $order
     * @param array $items
     * @param $rmaId
     */
    protected function createChangeSizeOrder($order, array $items,$rmaId, array $parentProducts){

        $orderData =[
            'order' => $order,
            'items' => $items,
            'rma_id'=>$rmaId,
            'parent_product_sku' => $parentProducts
        ];
        $this->changeSizeOrder->createMageOrder($orderData);
    }
}